==> blesta-5.10.2.zip: blesta/plugins/domains/language/zh_cn/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.zh_cn
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.getmodulefields.auto_choose'] = '-- 选择自动';
$lang['AdminMain.edit.title_basic_options'] = '基本选项';
$lang['AdminMain.edit.title_actions'] = '行动';
$lang['AdminMain.edit.title_domain_information'] = '域名信息';
$lang['AdminMain.edit.term_years'] = '%1$s 年';
$lang['AdminMain.edit.term_year'] = '%1$s 年';
$lang['AdminMain.edit.term_months'] = '%1$s 个月';
$lang['AdminMain.edit.term_month'] = '%1$s 月份';
$lang['AdminMain.edit.term_weeks'] = '%1$s 周';
$lang['AdminMain.edit.term_week'] = '%1$s 周';
$lang['AdminMain.edit.term_days'] = '%1$s 天';
$lang['AdminMain.edit.term_day'] = '%1$s 日';
$lang['AdminMain.edit.text_date_canceled'] = '取消日期：';
$lang['AdminMain.edit.text_date_suspended'] = '暂停日期：';
$lang['AdminMain.edit.text_date_last_renewed'] = '最后更新日期：';
$lang['AdminMain.edit.text_never'] = '从不';
$lang['AdminMain.edit.text_date_expires'] = '过期日期：';
$lang['AdminMain.edit.text_date_renews'] = '续订日期：';
$lang['AdminMain.edit.text_date_added'] = '创建日期：';
$lang['AdminMain.edit.text_status'] = '现状';
$lang['AdminMain.edit.text_years'] = '注册年份：';
$lang['AdminMain.edit.text_registrar'] = '登记员';
$lang['AdminMain.edit.text_domain'] = '领域：';
$lang['AdminMain.edit.field_edit_service'] = '编辑服务';
$lang['AdminMain.edit.field_activate'] = '激活';
$lang['AdminMain.edit.field_submit'] = '更新';
$lang['AdminMain.edit.field_notify_order'] = '激活后发送订单确认电子邮件';
$lang['AdminMain.edit.field_use_module'] = '使用模块';
$lang['AdminMain.edit.field_module'] = '注册模块';
$lang['AdminMain.edit.field_client'] = '客户';
$lang['AdminMain.edit.field_ns5'] = '名称服务器 5';
$lang['AdminMain.edit.field_ns4'] = '名称服务器 4';
$lang['AdminMain.edit.field_ns3'] = '名称服务器 3';
$lang['AdminMain.edit.field_ns2'] = '名称服务器 2';
$lang['AdminMain.edit.field_ns1'] = '名称服务器 1';
$lang['AdminMain.edit.field_auto_renewal'] = '启用自动续订';
$lang['AdminMain.edit.field_years'] = '年数';
$lang['AdminMain.edit.field_action'] = '行动';
$lang['AdminMain.edit.link_viewclient'] = '查看客户';
$lang['AdminMain.edit.boxtitle_edit'] = '编辑域： %1$s';
$lang['AdminMain.edit.boxtitle_client'] = '客户 #%1$s';
$lang['AdminMain.add_confirmation.discount'] = '折扣：';
$lang['AdminMain.add_confirmation.subtotal'] = '小计';
$lang['AdminMain.add_confirmation.price'] = '价格';
$lang['AdminMain.add_confirmation.qty'] = '数量';
$lang['AdminMain.add_confirmation.description'] = '说明';
$lang['AdminMain.add_confirmation.type_transfer'] = '转让';
$lang['AdminMain.add_confirmation.type_register'] = '注册';
$lang['AdminMain.add_confirmation.field_edit'] = '编辑';
$lang['AdminMain.add_confirmation.field_add'] = '添加域名';
$lang['AdminMain.add_confirmation.field_update_coupon'] = '更新';
$lang['AdminMain.add_confirmation.field_coupon_code'] = '优惠券代码';
$lang['AdminMain.add_confirmation.field_price'] = '价格';
$lang['AdminMain.add_confirmation.field_type'] = '类型';
$lang['AdminMain.add_confirmation.field_years'] = '年：';
$lang['AdminMain.add_confirmation.field_domain'] = '领域：';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = '没有';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = '是';
$lang['AdminMain.add_confirmation.field_notify_order'] = '发送订单确认电子邮件：';
$lang['AdminMain.add_confirmation.field_module'] = '注册单元：';
$lang['AdminMain.add_confirmation.field_status'] = '状态';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = '不开发票';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = '追加到发票 %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = '创建新发票';
$lang['AdminMain.add_confirmation.field_invoice_method'] = '发票方式：';
$lang['AdminMain.add.edit_package_pricing'] = '编辑定价';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s（续订 @ %3$s）。';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = '所选订单';
$lang['AdminMain.add.term_years'] = '%1$s 年';
$lang['AdminMain.add.term_year'] = '%1$s 年';
$lang['AdminMain.add.term_months'] = '%1$s 个月';
$lang['AdminMain.add.term_month'] = '%1$s 月份';
$lang['AdminMain.add.term_weeks'] = '%1$s 周';
$lang['AdminMain.add.term_week'] = '%1$s 周';
$lang['AdminMain.add.term_days'] = '%1$s 天';
$lang['AdminMain.add.term_day'] = '%1$s 日';
$lang['AdminMain.add.text_domain_unavailable'] = '不可用';
$lang['AdminMain.add.text_domain_available'] = '可用';
$lang['AdminMain.add.heading_options'] = '选项';
$lang['AdminMain.add.heading_status'] = '现状';
$lang['AdminMain.add.heading_domain'] = '域名';
$lang['AdminMain.add.title_registrar_options'] = '注册商选项';
$lang['AdminMain.add.title_basic_options'] = '基本选项';
$lang['AdminMain.add.title_search_results'] = '搜索结果';
$lang['AdminMain.add.field_notify_order'] = '激活后发送订单确认电子邮件';
$lang['AdminMain.add.field_use_module'] = '激活后使用注册商模块配置域名';
$lang['AdminMain.add.field_module'] = '注册模块';
$lang['AdminMain.add.field_status'] = '现状';
$lang['AdminMain.add.field_years'] = '年数';
$lang['AdminMain.add.field_invoice_method_dont'] = '不开发票';
$lang['AdminMain.add.field_invoice_method_append'] = '附加到现有发票';
$lang['AdminMain.add.field_invoice_method_create'] = '创建新发票';
$lang['AdminMain.add.field_invoice_method'] = '发票方式';
$lang['AdminMain.add.field_submit'] = '继续';
$lang['AdminMain.add.field_lookup'] = '查询可用性';
$lang['AdminMain.add.field_add'] = '添加域名';
$lang['AdminMain.add.field_register'] = '注册';
$lang['AdminMain.add.field_transfer'] = '转让';
$lang['AdminMain.add.link_viewclient'] = '查看客户';
$lang['AdminMain.add.boxtitle_add'] = '添加域名： %1$s';
$lang['AdminMain.add.boxtitle_client'] = '客户 #%1$s';
$lang['AdminMain.index.unparent'] = '非亲和重置价格';
$lang['AdminMain.!error.unsupported_domain'] = '不支持域名。';
$lang['AdminMain.!success.service_edited'] = '域名已成功更新！';
$lang['AdminMain.!success.domain_add'] = '域名已成功添加！';
$lang['AdminMain.!success.domain_transfer'] = '域名已成功转移！';
$lang['AdminMain.!success.domain_register'] = '域名已注册成功！';
$lang['AdminMain.!success.domains_unparented'] = '所选域已从父服务中删除，价格已成功重置！';
$lang['AdminMain.getfilters.field_service_meta'] = '域名';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = '任何';
$lang['AdminMain.domains.action.field_client'] = '客户';
$lang['AdminMain.domains.action.field_nameservers'] = '名称服务器';
$lang['AdminMain.domains.action.field_years'] = '年数';
$lang['AdminMain.index.field_actionsubmit'] = '提交';
$lang['AdminMain.index.domain_push_to_client'] = '推送到客户端';
$lang['AdminMain.index.update_nameservers'] = '更新域名服务器';
$lang['AdminMain.index.domain_renewal'] = '更新域名';
$lang['AdminMain.index.change_auto_renewal'] = '更改自动续订';
$lang['AdminMain.index.text_off'] = '关闭';
$lang['AdminMain.index.text_on'] = '关于';
$lang['AdminMain.index.text_never'] = '从不';
$lang['AdminMain.index.no_results'] = '没有具有这种状态的服务。';
$lang['AdminMain.index.confirm_delete'] = '您确定要删除这项服务吗？';
$lang['AdminMain.index.option_delete'] = '删除';
$lang['AdminMain.index.option_manage'] = '管理';
$lang['AdminMain.index.option_parent'] = '家长';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = '新领域';
$lang['AdminMain.index.category_canceled'] = '已取消';
$lang['AdminMain.index.category_suspended'] = '暂停';
$lang['AdminMain.index.category_pending'] = '待定';
$lang['AdminMain.index.category_active'] = '活跃';
$lang['AdminMain.index.heading_options'] = '选项';
$lang['AdminMain.index.heading_datecanceled'] = '取消日期';
$lang['AdminMain.index.heading_datesuspended'] = '暂停日期';
$lang['AdminMain.index.heading_dateexpires'] = '到期日期';
$lang['AdminMain.index.heading_daterenews'] = '续订日期';
$lang['AdminMain.index.heading_datecreated'] = '创建日期';
$lang['AdminMain.index.heading_term'] = '学期';
$lang['AdminMain.index.heading_domain'] = '域名';
$lang['AdminMain.index.heading_status'] = '现状';
$lang['AdminMain.index.heading_addons'] = '附加组件';
$lang['AdminMain.index.boxtitle_domains'] = '领域';
$lang['AdminMain.index.page_title'] = '客户 #%1$s 域名';
$lang['AdminMain.!success.domains_pushed'] = '所选域已成功推送到新客户端。';
$lang['AdminMain.!success.update_nameservers'] = '域名服务器已更新！';
$lang['AdminMain.!success.domain_renewal'] = '域名已续期！';
$lang['AdminMain.!success.change_auto_renewal'] = '域名自动更新已更新！';
$lang['AdminMain.!success.domain_registrar_updated'] = '域名注册商已更新！';
$lang['AdminMain.index.heading_registrar'] = '登记员';
$lang['AdminMain.index.heading_dateregistration'] = '注册日期';
$lang['AdminMain.index.text_date_added'] = '添加日期';
$lang['AdminMain.edit.text_registration_date'] = '注册日期：';

==> blesta-5.11.4.zip: blesta/plugins/domains/language/zh_cn/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.zh_cn
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.getmodulefields.auto_choose'] = '-- 选择自动';
$lang['AdminMain.edit.title_basic_options'] = '基本选项';
$lang['AdminMain.edit.title_actions'] = '行动';
$lang['AdminMain.edit.title_domain_information'] = '域名信息';
$lang['AdminMain.edit.term_years'] = '%1$s 年';
$lang['AdminMain.edit.term_year'] = '%1$s 年';
$lang['AdminMain.edit.term_months'] = '%1$s 个月';
$lang['AdminMain.edit.term_month'] = '%1$s 月份';
$lang['AdminMain.edit.term_weeks'] = '%1$s 周';
$lang['AdminMain.edit.term_week'] = '%1$s 周';
$lang['AdminMain.edit.term_days'] = '%1$s 天';
$lang['AdminMain.edit.term_day'] = '%1$s 日';
$lang['AdminMain.edit.text_date_canceled'] = '取消日期：';
$lang['AdminMain.edit.text_date_suspended'] = '暂停日期：';
$lang['AdminMain.edit.text_date_last_renewed'] = '最后更新日期：';
$lang['AdminMain.edit.text_never'] = '从不';
$lang['AdminMain.edit.text_date_expires'] = '过期日期：';
$lang['AdminMain.edit.text_date_renews'] = '续订日期：';
$lang['AdminMain.edit.text_date_added'] = '创建日期：';
$lang['AdminMain.edit.text_status'] = '现状';
$lang['AdminMain.edit.text_years'] = '注册年份：';
$lang['AdminMain.edit.text_registrar'] = '登记员';
$lang['AdminMain.edit.text_domain'] = '领域：';
$lang['AdminMain.edit.field_edit_service'] = '编辑服务';
$lang['AdminMain.edit.field_activate'] = '激活';
$lang['AdminMain.edit.field_submit'] = '更新';
$lang['AdminMain.edit.field_notify_order'] = '激活后发送订单确认电子邮件';
$lang['AdminMain.edit.field_use_module'] = '使用模块';
$lang['AdminMain.edit.field_module'] = '注册模块';
$lang['AdminMain.edit.field_client'] = '客户';
$lang['AdminMain.edit.field_ns5'] = '名称服务器 5';
$lang['AdminMain.edit.field_ns4'] = '名称服务器 4';
$lang['AdminMain.edit.field_ns3'] = '名称服务器 3';
$lang['AdminMain.edit.field_ns2'] = '名称服务器 2';
$lang['AdminMain.edit.field_ns1'] = '名称服务器 1';
$lang['AdminMain.edit.field_auto_renewal'] = '启用自动续订';
$lang['AdminMain.edit.field_years'] = '年数';
$lang['AdminMain.edit.field_action'] = '行动';
$lang['AdminMain.edit.link_viewclient'] = '查看客户';
$lang['AdminMain.edit.boxtitle_edit'] = '编辑域： %1$s';
$lang['AdminMain.edit.boxtitle_client'] = '客户 #%1$s';
$lang['AdminMain.add_confirmation.discount'] = '折扣：';
$lang['AdminMain.add_confirmation.subtotal'] = '小计';
$lang['AdminMain.add_confirmation.price'] = '价格';
$lang['AdminMain.add_confirmation.qty'] = '数量';
$lang['AdminMain.add_confirmation.description'] = '说明';
$lang['AdminMain.add_confirmation.type_transfer'] = '转让';
$lang['AdminMain.add_confirmation.type_register'] = '注册';
$lang['AdminMain.add_confirmation.field_edit'] = '编辑';
$lang['AdminMain.add_confirmation.field_add'] = '添加域名';
$lang['AdminMain.add_confirmation.field_update_coupon'] = '更新';
$lang['AdminMain.add_confirmation.field_coupon_code'] = '优惠券代码';
$lang['AdminMain.add_confirmation.field_price'] = '价格';
$lang['AdminMain.add_confirmation.field_type'] = '类型';
$lang['AdminMain.add_confirmation.field_years'] = '年：';
$lang['AdminMain.add_confirmation.field_domain'] = '领域：';
$lang['AdminMain.add_confirmation.field_notify_order_false'] = '没有';
$lang['AdminMain.add_confirmation.field_notify_order_true'] = '是';
$lang['AdminMain.add_confirmation.field_notify_order'] = '发送订单确认电子邮件：';
$lang['AdminMain.add_confirmation.field_module'] = '注册单元：';
$lang['AdminMain.add_confirmation.field_status'] = '状态';
$lang['AdminMain.add_confirmation.field_invoice_method_dont'] = '不开发票';
$lang['AdminMain.add_confirmation.field_invoice_method_append'] = '追加到发票 %1$s';
$lang['AdminMain.add_confirmation.field_invoice_method_create'] = '创建新发票';
$lang['AdminMain.add_confirmation.field_invoice_method'] = '发票方式：';
$lang['AdminMain.add.edit_package_pricing'] = '编辑定价';
$lang['AdminMain.add.term_recurring'] = '%1$s @ %2$s（续订 @ %3$s）。';
$lang['AdminMain.add.term'] = '%1$s @ %2$s';
$lang['AdminMain.add.order_btn'] = '所选订单';
$lang['AdminMain.add.term_years'] = '%1$s 年';
$lang['AdminMain.add.term_year'] = '%1$s 年';
$lang['AdminMain.add.term_months'] = '%1$s 个月';
$lang['AdminMain.add.term_month'] = '%1$s 月份';
$lang['AdminMain.add.term_weeks'] = '%1$s 周';
$lang['AdminMain.add.term_week'] = '%1$s 周';
$lang['AdminMain.add.term_days'] = '%1$s 天';
$lang['AdminMain.add.term_day'] = '%1$s 日';
$lang['AdminMain.add.text_domain_unavailable'] = '不可用';
$lang['AdminMain.add.text_domain_available'] = '可用';
$lang['AdminMain.add.heading_options'] = '选项';
$lang['AdminMain.add.heading_status'] = '现状';
$lang['AdminMain.add.heading_domain'] = '域名';
$lang['AdminMain.add.title_registrar_options'] = '注册商选项';
$lang['AdminMain.add.title_basic_options'] = '基本选项';
$lang['AdminMain.add.title_search_results'] = '搜索结果';
$lang['AdminMain.add.field_notify_order'] = '激活后发送订单确认电子邮件';
$lang['AdminMain.add.field_use_module'] = '激活后使用注册商模块配置域名';
$lang['AdminMain.add.field_module'] = '注册模块';
$lang['AdminMain.add.field_status'] = '现状';
$lang['AdminMain.add.field_years'] = '年数';
$lang['AdminMain.add.field_invoice_method_dont'] = '不开发票';
$lang['AdminMain.add.field_invoice_method_append'] = '附加到现有发票';
$lang['AdminMain.add.field_invoice_method_create'] = '创建新发票';
$lang['AdminMain.add.field_invoice_method'] = '发票方式';
$lang['AdminMain.add.field_submit'] = '继续';
$lang['AdminMain.add.field_lookup'] = '查询可用性';
$lang['AdminMain.add.field_add'] = '添加域名';
$lang['AdminMain.add.field_register'] = '注册';
$lang['AdminMain.add.field_transfer'] = '转让';
$lang['AdminMain.add.link_viewclient'] = '查看客户';
$lang['AdminMain.add.boxtitle_add'] = '添加域名： %1$s';
$lang['AdminMain.add.boxtitle_client'] = '客户 #%1$s';
$lang['AdminMain.index.unparent'] = '非亲和重置价格';
$lang['AdminMain.!error.unsupported_domain'] = '不支持域名。';
$lang['AdminMain.!success.service_edited'] = '域名已成功更新！';
$lang['AdminMain.!success.domain_add'] = '域名已成功添加！';
$lang['AdminMain.!success.domain_transfer'] = '域名已成功转移！';
$lang['AdminMain.!success.domain_register'] = '域名已注册成功！';
$lang['AdminMain.!success.domains_unparented'] = '所选域已从父服务中删除，价格已成功重置！';
$lang['AdminMain.getfilters.field_service_meta'] = '域名';
$lang['AdminMain.getfilters.field_package_name'] = 'TLD';
$lang['AdminMain.getfilters.any'] = '任何';
$lang['AdminMain.domains.action.field_client'] = '客户';
$lang['AdminMain.domains.action.field_nameservers'] = '名称服务器';
$lang['AdminMain.domains.action.field_years'] = '年数';
$lang['AdminMain.index.field_actionsubmit'] = '提交';
$lang['AdminMain.index.domain_push_to_client'] = '推送到客户端';
$lang['AdminMain.index.update_nameservers'] = '更新域名服务器';
$lang['AdminMain.index.domain_renewal'] = '更新域名';
$lang['AdminMain.index.change_auto_renewal'] = '更改自动续订';
$lang['AdminMain.index.text_off'] = '关闭';
$lang['AdminMain.index.text_on'] = '关于';
$lang['AdminMain.index.text_never'] = '从不';
$lang['AdminMain.index.no_results'] = '没有具有这种状态的服务。';
$lang['AdminMain.index.confirm_delete'] = '您确定要删除这项服务吗？';
$lang['AdminMain.index.option_delete'] = '删除';
$lang['AdminMain.index.option_manage'] = '管理';
$lang['AdminMain.index.option_parent'] = '家长';
$lang['AdminMain.index.recurring_term'] = '%1$s %2$s @ %3$s';
$lang['AdminMain.index.categorylink_newservice'] = '新领域';
$lang['AdminMain.index.category_canceled'] = '已取消';
$lang['AdminMain.index.category_suspended'] = '暂停';
$lang['AdminMain.index.category_pending'] = '待定';
$lang['AdminMain.index.category_active'] = '活跃';
$lang['AdminMain.index.heading_options'] = '选项';
$lang['AdminMain.index.heading_datecanceled'] = '取消日期';
$lang['AdminMain.index.heading_datesuspended'] = '暂停日期';
$lang['AdminMain.index.heading_dateexpires'] = '到期日期';
$lang['AdminMain.index.heading_daterenews'] = '续订日期';
$lang['AdminMain.index.heading_datecreated'] = '创建日期';
$lang['AdminMain.index.heading_term'] = '学期';
$lang['AdminMain.index.heading_domain'] = '域名';
$lang['AdminMain.index.heading_status'] = '现状';
$lang['AdminMain.index.heading_addons'] = '附加组件';
$lang['AdminMain.index.boxtitle_domains'] = '领域';
$lang['AdminMain.index.page_title'] = '客户 #%1$s 域名';
$lang['AdminMain.!success.domains_pushed'] = '所选域已成功推送到新客户端。';
$lang['AdminMain.!success.update_nameservers'] = '域名服务器已更新！';
$lang['AdminMain.!success.domain_renewal'] = '域名已续期！';
$lang['AdminMain.!success.change_auto_renewal'] = '域名自动更新已更新！';
$lang['AdminMain.!success.domain_registrar_updated'] = '域名注册商已更新！';
$lang['AdminMain.index.heading_registrar'] = '登记员';
$lang['AdminMain.index.heading_dateregistration'] = '注册日期';
$lang['AdminMain.index.text_date_added'] = '添加日期';
$lang['AdminMain.edit.text_registration_date'] = '注册日期：';
$lang['AdminMain.edit.field_registration_date'] = '更改注册日期';
$lang['AdminMain.edit.field_expiration_date'] = '更改有效期';
$lang['AdminMain.!success.change_registration_date'] = '域名注册日期已更新！';
$lang['AdminMain.!success.change_expiration_date'] = '域名到期日期已更新！';
